
/* 
    etx_test.c
    version 1.0

   (c) 2001 Lionel Moisan
*/


/*------------- Low level Autostar most useful commands -------------

=== prefix to all commands: ":"
=== suffix to all commands: "#"
=== all autostar answers terminate by #
===  means the character  (0xdf)
===  means ASCII code 0x7f

Me Mw Mn Ms : move (east, west, north, south)
Qe Qw Qn Qs Q : stop moving (REMAINING direction if specified)

Sw2 Sw3 Sw4 : set motion speed (slow-intermediate-fast)

^F (ASCII 6) : get alignment  -> A

AA : set alignment to AltAz

GL : get time (24h)       -> 20:24:59
SL12:32:05 : set local time -> 1

GC : get date             -> 02/13/01
SC02/16/01 : set date     -> "1Updating planetary data        "

GS : get sideral time     -> 00:31:11

GM : get site #1 name     -> PARIS
GN : get site #2 name     -> <AN_UNUSED_SITE>
GO : get site #3 name     -> <AN_UNUSED_SITE>
GP : get site #4 name     -> <AN_UNUSED_SITE>
Gg : get site longitude   -> 00000
Gg : get site lattitude   -> +0000
W1/W2/W3/W4 : set site

U : toggles long format (seems to have no effect on precision)

GD : get Tel. declination -> +0358 (increases north, start at +0000)
GA : get Tel. altitude    -> +0358 (idem but absolute)

GR : get Tel. RA          -> 12:46.2 (increases right, start at 00000)
GZ : get Tel. azimuth     -> 00419 (idem but absolute)

Gd : get Obj. declination -> +0000
Sd : set Obj. declination -> 1 (ex: Sd+0130)

Gr : get Obj. RA          -> 00:00.0
Sr : set Obj. RA          -> 1 

CM : match Tel. to Obj.   -> sends "  M31" and starts moving

D : distance to target ->  or nothing
 
----------------------------------------------------------- */



#include <stdio.h>
#include <string.h>
#include <fcntl.h>
#include <sys/time.h>
#include <time.h>
#include <sys/types.h>
#include <unistd.h>
#include <termios.h>

static struct termios ios,my_ios;

void send_command(fd,in,out)
int fd;
char *in,*out;
{
  int n,i;

  for (i=0;i<strlen(in);i++) {
    if (in[i]=='') in[i]='';
  }
  printf("send %s\n",in);
  write(fd,in,strlen(in));
  do {
    usleep(100000);
    n = read(fd,out,255);
    for (i=0;i<n;i++) {
      if (out[i]=='') out[i]='';
      if (out[i]==127) out[i]='';
    }
    out[n]=(char)0;
    if (n) printf("answer (%d bytes read): %s\n",n,out);
  } while (n==255);
}

main()
{
  int fd,quit;
  char buf[256],str[100],com[100];

  /* open and configure serial port */
  fd = open("/dev/ttyS0",O_RDWR | O_NOCTTY );
  if (fd!=-1) printf("serial port opened.\n"); 
  else {
    printf("cannot open serial port. Exit.\n");
    exit(1);
  }
  if(tcgetattr(fd, &ios)== -1) {
    perror("tcgetattr failed\n");
    exit(1);
  }
  memcpy(&my_ios, &ios, sizeof(struct termios));
  cfmakeraw(&my_ios);
  my_ios.c_cc[VMIN] = 0;
  my_ios.c_cc[VTIME] = 5;
  cfsetispeed(&my_ios, B9600); /* 9600 bauds */
  cfsetospeed(&my_ios, B9600); /* 9600 bauds */
  tcsetattr(fd, TCSANOW, &my_ios);

  printf("===================================================\n");
  printf("Now you can send commands to the ETX\n");
  printf("example : Me then Q\n");
  printf("prefix ':' and suffix '#' are added automatically\n");
  printf("===================================================\n");
  do {
    printf("Enter string ('*' to quit) : ");
    fflush(stdout);
    scanf("%s",str);
    quit = (strcmp(str,"*")==0);
    if (!quit) {
      sprintf(com,":%s#",str);
      send_command(fd,com,&buf);
    }
  } while (!quit);

  /* close serial port */
  close(fd);
  printf("===================================================\n");
  printf("serial port closed.\n");
}
